@@ -55,6 +55,7 @@ class CutestyleFormatter(Formatter):
         self.refresh()
 
     def refresh(self):
+
         # Tags colors
         self.TAGS_COLOR = {}
         config = Config("tags")
@@ -63,14 +64,33 @@ class CutestyleFormatter(Formatter):
         ):
             self.TAGS_COLOR[tag["name"]] = tag["color"]
 
-    def format(self, field: str, value: str, option, is_selected):
+         # Classification genotypes
+        self.CLASSIFICATIONS_GENOTYPES = {}
+        classifications_genotypes = Config("classifications").get("genotypes", {})
+        for classification in classifications_genotypes:
+            self.CLASSIFICATIONS_GENOTYPES[classification["number"]] = classification
 
+    def format(self, field: str, value: str, option, is_selected):
+        
         if re.match(r"samples\..+\.gt", field) or field == "gt":
-            if value == "NULL":
+            if value == "NULL" or value is None or value == "":
                 value = -1
-            icon = cst.GENOTYPE_ICONS.get(int(value))
+            else:
+                value = int(value)
+            icon = cst.GENOTYPE_ICONS.get(value)            
             return {"text": "", "icon": FIcon(icon)}
 
+        if re.match(r"samples\..+\.classification", field):
+            if value == "NULL":
+                return {"text": ""}
+            else:
+                genotype_classification_color = self.CLASSIFICATIONS_GENOTYPES.get(int(value),{}).get("color","gray")
+                if int(value) != 0:
+                    genotype_classification_icon = 0xF0133
+                else:
+                    genotype_classification_icon = 0xF0130 #0xF0130 #0xF012F
+                return {"text": "", "color": genotype_classification_color, "icon": FIcon(genotype_classification_icon, color=genotype_classification_color)}
+
         if value == "NULL" or value == "None":
             font = QFont()
             font.setItalic(True)
