@@ -88,11 +88,13 @@ class GenotypeVerticalHeader(QHeaderView):
                     [genotype_sample_name],
                 )
             )
-            genotype = genotype_infos["gt"]
-        if genotype:
-            genotype_int = int(genotype)
-        else:
+            genotype = genotype_infos.get("gt", -1)
+
+        if genotype == "NULL" or genotype is None or genotype == "":
             genotype_int = -1
+        else:
+            genotype_int = int(genotype)
+
         pix_icon = GENOTYPE_ICONS.get(genotype_int)  # , GENOTYPE_ICONS[-1])
         pix_icon.engine.setColor(color)
 
@@ -208,7 +210,7 @@ class GenotypeModel(QAbstractTableModel):
         key = self._headers[index.column()]
 
         if role == Qt.DisplayRole:
-            return item[key] or "NULL"
+            return item[key]
 
         if role == Qt.ToolTipRole:
             return self.get_tooltip(index.row())
@@ -277,7 +279,7 @@ class GenotypeModel(QAbstractTableModel):
 
         # Create load_func to run asynchronously: load samples
 
-        used_fields = copy.deepcopy(self.get_fields()) or ["gt"]
+        used_fields = copy.deepcopy(self.get_fields()) or []
         if "classification" not in used_fields:
             used_fields.append("classification")
 
@@ -429,7 +431,9 @@ class GenotypesWidget(plugin.PluginWidget):
 
         self.view.setVerticalHeader(GenotypeVerticalHeader())
         self.view.verticalHeader().setSectionsClickable(True)
-        self.view.verticalHeader().sectionDoubleClicked.connect(self._on_double_clicked_vertical_header)
+        self.view.verticalHeader().sectionDoubleClicked.connect(
+            self._on_double_clicked_vertical_header
+        )
 
         self.view.setItemDelegate(self.delegate)
 
@@ -606,7 +610,7 @@ class GenotypesWidget(plugin.PluginWidget):
         self.on_refresh()
 
     def _on_double_clicked(self):
-        self._show_sample_variant_dialog()
+        self._on_default_classification_changed()
 
     def _on_double_clicked_vertical_header(self):
         self._show_sample_variant_dialog()
@@ -667,7 +671,7 @@ class GenotypesWidget(plugin.PluginWidget):
 
             tags_preset = Config("tags")
 
-            for item in tags_preset.get("genotypes",[]):
+            for item in tags_preset.get("genotypes", []):
 
                 icon = 0xF04F9
 
@@ -688,7 +692,7 @@ class GenotypesWidget(plugin.PluginWidget):
         Returns:
             locked (bool) : lock status of sample attached to current genotype
         """
-        config_classif = Config("classifications").get("samples", None)
+        config_classif = Config("classifications").get("samples", [])
         sample = sql.get_sample(self.conn, sample_id)
         sample_classif = sample.get("classification", None)
 
@@ -733,10 +737,11 @@ class GenotypesWidget(plugin.PluginWidget):
 
         else:
             QMessageBox.information(
-                self, "No genotype", self.tr(f"Sample '{sample_name}' does not have genotype for this variant")
+                self,
+                "No genotype",
+                self.tr(f"Sample '{sample_name}' does not have genotype for this variant"),
             )
 
-
     def _toggle_column(self, col: int, show: bool):
         """hide/show columns"""
         if show:
@@ -744,25 +749,74 @@ class GenotypesWidget(plugin.PluginWidget):
         else:
             self.view.hideColumn(col)
 
-    def _on_classification_changed(self):
+    def _on_classification_changed(self, value: int = None):
         """triggered from menu"""
         if not self.sender():
             return
 
-        value = self.sender().data()
-        text = self.sender().text()
+        genotype = self.model.get_genotype(self.view.selectionModel().selectedRows()[0].row())
 
-        rows = [i.row() for i in self.view.selectionModel().selectedRows()]
-        self.model.edit(rows, {"classification": value})
+        value = int(value)
 
-        if "samples" in self.mainwindow.plugins:
-            self.mainwindow.refresh_plugin("samples")
+        if value:
+            if (
+                len(self.view.selectionModel().selectedRows()) == 1
+                and genotype.get("classification") == value
+            ):
+                value = 0
+        else:
+            try:
+                value = self.sender().data()
+            except:
+                value = 0
+
+        if (
+            genotype.get("sample_id", None) is not None
+            and genotype.get("variant_id", None) is not None
+        ):
+
+            if self.is_locked(genotype.get("sample_id", 0)):
+                sample_name = genotype.get("name", "unknown")
+                QMessageBox.information(
+                    self, "Sample is locked", self.tr(f"Sample '{sample_name}' is locked")
+                )
+                return
+
+            rows = [i.row() for i in self.view.selectionModel().selectedRows()]
+            self.model.edit(rows, {"classification": value})
+
+            if "samples" in self.mainwindow.plugins:
+                self.mainwindow.refresh_plugin("samples")
+
+            if "variant_view" in self.mainwindow.plugins:
+                fields = self.mainwindow.get_state_data("fields")
+                for field in fields:
+                    if re.findall(r"^samples.(\w+)\.classification$", field):
+                        self.mainwindow.refresh_plugin("variant_view")
+                        break
+
+    def _on_default_classification_changed(self):
+        # default_classification_validation
+        global_variables = Config("genotypes")
+        default_classification_genotype_validation = global_variables.get(
+            "default_classification_validation", 1
+        )
+        # genotypes classifications
+        classifications = Config("classifications")
+        genotypes_classification = classifications.get("genotypes", [])
+        # test if classification 1 exists, else 0
+        classification_genotype_validation = 0
+        for classification in genotypes_classification:
+            if classification.get("number", 0) == default_classification_genotype_validation:
+                classification_genotype_validation = default_classification_genotype_validation
+        # change clssification
+        self._on_classification_changed(classification_genotype_validation)
 
     def _on_tags_changed(self, tags: list = []):
         """triggered from menu"""
 
         for index in self.view.selectionModel().selectedRows():
-            
+
             # current variant sample
             row = index.row()
             genotype = self.model.get_genotype(row)
@@ -770,12 +824,14 @@ class GenotypesWidget(plugin.PluginWidget):
             genotype_sample_name = genotype["name"]
 
             # current variant tags
-            current_genotype = next(sql.get_genotypes(
+            current_genotype = next(
+                sql.get_genotypes(
                     self.conn,
                     genotype_variant_id,
                     ["tags"],
                     [genotype_sample_name],
-                ))
+                )
+            )
             current_tags_text = current_genotype.get("tags", None)
             if current_tags_text:
                 current_tags = current_tags_text.split(cst.HAS_OPERATOR)
@@ -871,6 +927,9 @@ class GenotypesWidget(plugin.PluginWidget):
 
         config = Config("classifications")
         self.model.classifications = config.get("genotypes", [])
+        self.model.classifications = sorted(
+            self.model.classifications, key=lambda d: d.get("number", 0)
+        )
 
     def _is_selectors_checked(self):
         """Return False if selectors is not checked"""
@@ -891,6 +950,7 @@ class GenotypesWidget(plugin.PluginWidget):
             self.sample_selector.add_item(FIcon(0xF0B55), sample["name"], data=sample["name"])
 
     def load_fields(self):
+        self.fields_button.blockSignals(True)
         self.fields_button.clear()
         for field in sql.get_field_by_category(self.conn, "samples"):
             self.fields_button.add_item(
@@ -899,9 +959,9 @@ class GenotypesWidget(plugin.PluginWidget):
                 field["description"],
                 data=field["name"],
             )
+        self.fields_button.blockSignals(False)
 
     def on_refresh(self):
-
         # variant id
         self.current_variant = self.mainwindow.get_state_data("current_variant")
         if self.current_variant and "id" in self.current_variant:
