@@ -1,5 +1,5 @@
 __title__ = "Group by"
-__description__ = "The groupby view for variant selection view"
+__description__ = "Group variant by custom fields and show how many they are"
 __long_description__ = """This widget is directly linked to the variant view. 
 It displays, for the categorical field of your choice, the count of unique values in your selection."""
 __author__ = "Charles Monod-Broca"
