@@ -30,7 +30,7 @@ import cutevariant.constants as cst
 # TODO: to constants.py
 DEFAULT_SELECTION_NAME = "variants"  # cst.getDEFAULT_SELECTION_NAME
 SAMPLES_SELECTION_NAME = "samples"  # cst.SAMPLES_SELECTION_NAME
-CURRENT_SAMPLE_SELECTION_NAME = "current_sample"  # cst.SAMPLES_SELECTION_NAME
+CURRENT_SAMPLE_SELECTION_NAME = "current_samples"  # cst.SAMPLES_SELECTION_NAME
 LOCKED_SELECTIONS = [
     DEFAULT_SELECTION_NAME,
 ]
@@ -118,21 +118,27 @@ class SourceModel(QAbstractTableModel):
 
         if role == Qt.DecorationRole:
             if index.column() == 0:
+                color = QApplication.palette().color(QPalette.Text)
+                color_alpha = QColor(QApplication.palette().color(QPalette.Text))
+                color_alpha.setAlpha(50)
+                if table_name != self.current_source:
+                    color = color_alpha
                 # if table_name == DEFAULT_SELECTION_NAME:
                 if table_name in LOCKED_SELECTIONS:
-                    return QIcon(FIcon(0xF13C6))
+                    return QIcon(FIcon(0xF13C6, color))
                 else:
-                    return QIcon(FIcon(0xF04EB))
+                    return QIcon(FIcon(0xF04EB, color))
 
-        if role == Qt.FontRole:
-            font = QFont()
-            if table_name == self.current_source and index.column() == self.NAME_COLUMN:
-                font.setBold(True)
-                font.setUnderline(True)
-            return font
+        # if role == Qt.FontRole:
+        #     font = QFont()
+        #     font.setBold(table_name == self.current_source)
+        #     return font
 
-        if role == Qt.UserRole:
-            return self.records[index.row()]
+        # if role == Qt.ForegroundRole:
+        #     if table_name != self.current_source:
+        #         return QApplication.style().standardPalette().color(QPalette.Dark)
+        #     else:
+        #         return QApplication.style().standardPalette().color(QPalette.Light)
 
         if role == Qt.UserRole:
             return self.records[index.row()]
@@ -360,11 +366,13 @@ class SourceEditorWidget(plugin.PluginWidget):
 
     @Slot(QModelIndex)
     def on_double_click(self, current: QModelIndex):
-        source = current.data(Qt.DisplayRole)
+        source = current.siblingAtColumn(0).data(Qt.DisplayRole)
         if source:
             self.model.current_source = source
             self.mainwindow.set_state_data("source", source)
             self.mainwindow.refresh_plugins(sender=self)
+            if "samples" in self.mainwindow.plugins:
+                self.mainwindow.refresh_plugin("samples")
 
     def create_selection_from_current(self):
         name = self.ask_and_check_selection_name()
@@ -437,6 +445,9 @@ class SourceEditorWidget(plugin.PluginWidget):
         # model_index = self.model.find_record(self.source)
         # self.view.setCurrentIndex(model_index)
         # self.view.selectionModel().blockSignals(False)
+        if "plugins" in dir(self.mainwindow): # For FakeMainWindow
+            if "samples" in self.mainwindow.plugins:
+                self.mainwindow.refresh_plugin("samples")
 
     def on_selection_changed(
         self,
