@@ -7,15 +7,15 @@ VariantPopupMenu is also used in viewquerywidget for the same purpose.
 from logging import DEBUG
 
 # Qt imports
-from PySide2.QtCore import QModelIndex, Qt, Slot, QSize
-from PySide2.QtWidgets import *
-from PySide2.QtGui import QFont, QColor
+from PySide6.QtCore import QModelIndex, Qt, Slot, QSize
+from PySide6.QtWidgets import *
+from PySide6.QtGui import QFont, QColor
 
 # Custom imports
 from cutevariant.gui import FIcon, style
 from cutevariant.core import sql, get_sql_connection
 from cutevariant.gui.plugin import PluginWidget
-from cutevariant import commons as cm
+from cutevariant import constants as cst
 
 from cutevariant.gui.widgets import DictWidget
 
@@ -26,28 +26,59 @@ from cutevariant import LOGGER
 
 
 class VariantInfoModel(QJsonModel):
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self._headers = ["Fields", "Value"]
+        self.fields_descriptions = {}
+
+    @property
+    def conn(self):
+        return self._conn
+
+    @conn.setter
+    def conn(self, conn):
+        self._conn = conn
+        self.fields_descriptions = {f["name"]: f["description"] for f in sql.get_fields(conn)}
+
     def data(self, index: QModelIndex, role: Qt.ItemDataRole):
 
         item: QJsonTreeItem = index.internalPointer()
         value = item.value
 
-        if role == Qt.ForegroundRole and index.column() == 1:
+        # if role == Qt.ForegroundRole and index.column() == 1:
 
-            if value == "":
-                return Qt.gray
+        #     if value == "":
+        #         return Qt.gray
 
-            value_type = type(value).__name__
-            if value_type in style.FIELD_TYPE:
-                col = QColor(style.FIELD_TYPE[value_type]["color"])
-                return col
+        #     value_type = type(value).__name__
+        #     if value_type in style.FIELD_TYPE:
+        #         col = QColor(style.FIELD_TYPE[value_type]["color"])
+        #         return col
 
         if role == Qt.SizeHintRole:
             return QSize(30, 30)
 
+        if role == Qt.ToolTipRole:
+
+            if index.column() == 0:
+                # Return fields description
+                key = super().data(index, Qt.DisplayRole)
+                description = self.fields_descriptions.get(key, "")
+                return f"<b>{key}</b><br/>{description}"
+
+            if index.column() == 1:
+                # Return key values
+                return str(value)
+
         if role == Qt.DisplayRole and index.column() == 1:
             if value == "":
                 return item.childCount()
 
+        if role == Qt.FontRole and index.column() == 0:
+            font = QFont()
+            font.setBold(True)
+            return font
+
         return super().data(index, role)
 
     def flags(self, index):
@@ -57,23 +88,39 @@ class VariantInfoModel(QJsonModel):
 class VariantInfoWidget(PluginWidget):
     """Plugin to show all annotations of a selected variant"""
 
-    ENABLE = True
+    ENABLE = False
     REFRESH_STATE_DATA = {"current_variant"}
 
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.setWindowIcon(FIcon(0xF0B73))
         # Current variant => set by on_refresh and on_open_project
         self.current_variant = None
-        self.view = QTreeView()
+
         self.model = VariantInfoModel()
-        self.view.setModel(self.model)
+
+        self.proxy_model = QSortFilterProxyModel()
+        self.proxy_model.setSourceModel(self.model)
+        self.proxy_model.setRecursiveFilteringEnabled(True)
+
+        self.view = QTreeView()
+        self.view.setModel(self.proxy_model)
         self.view.setAlternatingRowColors(True)
+
+        self.search_bar = QLineEdit()
+        self.search_bar.textChanged.connect(self.proxy_model.setFilterFixedString)
+        self.search_bar.setPlaceholderText(self.tr("Search by keywords... "))
+        self.search_bar.addAction(FIcon(0xF015A), QLineEdit.TrailingPosition).triggered.connect(
+            self.search_bar.clear
+        )
+
         vlayout = QVBoxLayout()
         vlayout.addWidget(self.view)
+        vlayout.addWidget(self.search_bar)
         vlayout.setContentsMargins(0, 0, 0, 0)
+
         self.setLayout(vlayout)
+        self.setWindowIcon(FIcon(0xF0B73))
 
     #     self.view = QTabWidget()
     #     self.toolbar = QToolBar()
@@ -140,7 +187,7 @@ class VariantInfoWidget(PluginWidget):
     #     # Cache genotype icons
     #     # Values in gt field as keys (str), FIcon as values
     #     self.genotype_icons = {
-    #         key: FIcon(val) for key, val in cm.GENOTYPE_ICONS.items()
+    #         key: FIcon(val) for key, val in cst.GENOTYPE_ICONS.items()
     #     }
 
     # def clear(self):
@@ -171,14 +218,18 @@ class VariantInfoWidget(PluginWidget):
 
     def on_open_project(self, conn):
         self.conn = conn
+        self.model.conn = conn
 
     def on_refresh(self):
         """Set the current variant by the variant displayed in the GUI"""
         self.current_variant = self.mainwindow.get_state_data("current_variant")
 
-        results = sql.get_one_variant(self.conn, self.current_variant["id"], True, True)
+        results = sql.get_variant(self.conn, self.current_variant["id"], True, True)
 
         self.model.load(results)
+        self.view.expandAll()
+        self.view.header().setSectionResizeMode(0, QHeaderView.Stretch)
+        # self.view.header().setSectionResizeMode(1, QHeaderView.Fixed)
 
     # @Slot()
     # def on_save_clicked(self):
@@ -217,7 +268,7 @@ if __name__ == "__main__":
     w = VariantInfoWidget()
     w.conn = conn
 
-    variant = sql.get_one_variant(conn, 1)
+    variant = sql.get_variant(conn, 1)
 
     w.current_variant = variant
 
