@@ -383,29 +383,6 @@ class MemorySettings(AbstractSettingsWidget):
         pass
 
 
-class ClassificationSettings(AbstractSettingsWidget):
-    def __init__(self):
-        super().__init__()
-        self.setWindowTitle(self.tr("Classification"))
-        # self.setWindowIcon(FIcon(0xF070F))
-
-        layout = QVBoxLayout(self)
-        self.w = ClassificationEditor()
-        layout.addWidget(self.w)
-
-    def save(self):
-        """override"""
-        config = self.section_widget.create_config()
-        config["classifications"] = self.w.get_classifications()
-        config.save()
-
-    def load(self):
-        """override"""
-        config = self.section_widget.create_config()
-        classifications = config.get("classifications", [])
-        self.w.set_classifications(classifications)
-
-
 class VariantViewSettingsWidget(PluginSettingsWidget):
     """Instantiated plugin in the settings panel of Cutevariant
 
@@ -421,4 +398,3 @@ class VariantViewSettingsWidget(PluginSettingsWidget):
         self.setWindowTitle("Variant view")
         self.add_page(GeneralSettings())
         self.add_page(LinkSettings())
-        self.add_page(ClassificationSettings())
