@@ -50,6 +50,8 @@ from cutevariant.core.querybuilder import filters_to_flat
 
 from cutevariant.gui import tooltip as toolTip
 
+from cutevariant.gui.widgets import ChoiceButton
+
 
 class VariantVerticalHeader(QHeaderView):
     def __init__(self, parent=None):
@@ -73,17 +75,23 @@ class VariantVerticalHeader(QHeaderView):
 
             painter.restore()
 
-            classification = next(i for i in self.model().classifications if i["number"] == number)
+            if self.model().classifications:
+                classification = (
+                    next(i for i in self.model().classifications if i.get("number", None) == number)
+                    or {}
+                )
+            else:
+                classification = {}
 
-            color = classification.get("color")
+            color = classification.get("color", "white")
             icon = 0xF0130
 
             icon_favorite = 0xF0133
 
-            pen = QPen(QColor(classification.get("color")))
+            pen = QPen(QColor(classification.get("color", "white")))
             pen.setWidth(6)
             painter.setPen(pen)
-            painter.setBrush(QBrush(classification.get("color")))
+            painter.setBrush(QBrush(classification.get("color", "white")))
             painter.drawLine(rect.left(), rect.top() + 1, rect.left(), rect.bottom() - 1)
 
             target = QRect(0, 0, 20, 20)
@@ -182,6 +190,7 @@ class VariantModel(QAbstractTableModel):
 
         self._finished_thread_count = 0
         self._user_has_interrupt = False
+        self._is_loading = False
 
         # Create results cache because Thread doesn't use the memoization cache from command.py.
         # This is because Thread create a new connection and change the function signature used by the cache.
@@ -378,15 +387,16 @@ class VariantModel(QAbstractTableModel):
                 return QSize(0, 20)
 
         if orientation == Qt.Horizontal:
-            field_name = self.fields[section]
-            flattened_filters = filters_to_flat(self.filters)
-            col_filtered = any(field_name in f for f in flattened_filters)
-            if role == Qt.DecorationRole:
-                return QIcon(FIcon(0xF10E5)) if col_filtered else QIcon(FIcon(0xF0233))
-            if role == Qt.FontRole:
-                font = QFont()
-                font.setBold(col_filtered)
-                return font
+            if section in self.fields:
+                field_name = self.fields[section]
+                flattened_filters = filters_to_flat(self.filters)
+                col_filtered = any(field_name in f for f in flattened_filters)
+                if role == Qt.DecorationRole:
+                    return QIcon(FIcon(0xF10E5)) if col_filtered else QIcon(FIcon(0xF0233))
+                if role == Qt.FontRole:
+                    font = QFont()
+                    font.setBold(col_filtered)
+                    return font
 
         # vertical header
         if role == Qt.ToolTipRole and orientation == Qt.Vertical:
@@ -521,6 +531,7 @@ class VariantModel(QAbstractTableModel):
                 interrupted = True
 
         if interrupted:
+            self._is_loading = False
             self.interrupted.emit()
 
         # # Wait for exception ...
@@ -547,10 +558,11 @@ class VariantModel(QAbstractTableModel):
         if self.conn is None:
             return
 
-        if self.is_running():
+        if self.is_running() or self._is_loading:
             LOGGER.debug("Cannot load data. Thread is not finished. You can call interrupt() ")
             return
 
+        self._is_loading = True
         LOGGER.debug("Start loading")
         self.mutex.lock()
         offset = (self.page - 1) * self.limit
@@ -652,6 +664,7 @@ class VariantModel(QAbstractTableModel):
         if self._finished_thread_count == 2:
             self._end_timer = time.perf_counter()
             self.elapsed_time = self._end_timer - self._start_timer
+            self._is_loading = False
             self.load_finished.emit()
 
     def on_count_loaded(self):
@@ -670,6 +683,7 @@ class VariantModel(QAbstractTableModel):
         if self._finished_thread_count == 2:
             self._end_timer = time.perf_counter()
             self.elapsed_time = self._end_timer - self._start_timer
+            self._is_loading = False
             self.load_finished.emit()
 
     def hasPage(self, page: int) -> bool:
@@ -797,9 +811,10 @@ class VariantView(QWidget):
     field_remove = Signal(str)
 
     # Shortcut plugin action
-    fields_btn_clicked = Signal()
-    source_btn_clicked = Signal()
-    filters_btn_clicked = Signal()
+    fields_menu_changed = Signal(list)
+    source_menu_changed = Signal(str)
+    filters_menu_changed = Signal(dict)
+    vql_button_clicked = Signal()
 
     def __init__(self, parent=None):
         """
@@ -835,7 +850,9 @@ class VariantView(QWidget):
 
         self.view.setVerticalHeader(VariantVerticalHeader())
         self.view.verticalHeader().setSectionsClickable(True)
-        self.view.verticalHeader().sectionDoubleClicked.connect(self.on_double_clicked_vertical_header)
+        self.view.verticalHeader().sectionDoubleClicked.connect(
+            self.on_double_clicked_vertical_header
+        )
 
         self.view.setSortingEnabled(True)
         self.view.setSelectionBehavior(QAbstractItemView.SelectRows)
@@ -930,26 +947,40 @@ class VariantView(QWidget):
         )
         self.addAction(self.comment_action)
 
-        self.fields_button = self.top_bar.addAction(FIcon(0xF08DF), "Fields")
-        self.fields_button.triggered.connect(self.fields_btn_clicked)
-        self.fields_button.setToolTip("Edit Fields ")
-        self.source_button = self.top_bar.addAction(FIcon(0xF04EB), "Source")
-        self.source_button.triggered.connect(self.source_btn_clicked)
-        self.source_button.setToolTip("Edit Source ")
-        self.filters_button = self.top_bar.addAction(FIcon(0xF0232), "Filters")
-        self.filters_button.triggered.connect(self.filters_btn_clicked)
-        self.filters_button.setToolTip("Edit Filters ")
+        self.fields_button = QPushButton()
+        self.fields_menu = QMenu(self.fields_button)
+        self.fields_menu.triggered.connect(self.on_filter_menu_changed)
+        self.fields_button.setFlat(True)
+        self.fields_button.setToolTip(self.tr("Select a Field Preset"))
+        self.fields_button.setIcon(FIcon(0xF08DF))
+        self.fields_button.setMenu(self.fields_menu)
+
+        self.top_bar.addWidget(self.fields_button)
+
+        self.source_button = QPushButton()
+        self.source_menu = QMenu(self.source_button)
+        self.source_menu.triggered.connect(self.on_filter_menu_changed)
+        self.source_button.setFlat(True)
+        self.source_button.setToolTip("Select a data source")
+        self.source_button.setIcon(FIcon(0xF04EB))
+        self.source_button.setMenu(self.source_menu)
+        self.top_bar.addWidget(self.source_button)
+
+        self.filters_button = QPushButton()
+        self.filters_menu = QMenu(self.filters_button)
+        self.filters_menu.triggered.connect(self.on_filter_menu_changed)
+        self.filters_button.setFlat(True)
+        self.filters_button.setIcon(FIcon(0xF0232))
+        self.filters_button.setToolTip(self.tr("Select a filter preset"))
+        self.filters_button.setMenu(self.filters_menu)
+        self.top_bar.addWidget(self.filters_button)
 
         spacer = QWidget()
         spacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.top_bar.addWidget(spacer)
 
-        self.source_label = QLabel("source")
-        self.top_bar.addWidget(self.source_label)
-
-        spacer = QWidget()
-        spacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
-        self.top_bar.addWidget(spacer)
+        self.show_vql = self.top_bar.addAction(FIcon(0xF018D), "Show VQL")
+        self.show_vql.triggered.connect(self.vql_button_clicked)
         # -----------Resize action ----------
 
         self.resize_action = self.top_bar.addAction(FIcon(0xF142A), self.tr("Auto resize"))
@@ -1006,6 +1037,62 @@ class VariantView(QWidget):
         action.setToolTip(self.tr("Last page (%s)" % action.shortcut().toString()))
         self.pagging_actions.addAction(action)
 
+    def on_filter_menu_changed(self, action: QAction):
+        """Executed when filter button (fields,source,filters) changed
+
+        Args:
+            action (QAction): the action in the menu
+        """
+        if self.sender() == self.fields_menu:
+            self.fields_menu_changed.emit(action.data())
+
+        if self.sender() == self.source_menu:
+            self.source_menu_changed.emit(action.data())
+
+        if self.sender() == self.filters_menu:
+            self.filters_menu_changed.emit(action.data())
+
+    def load_button_menu(self):
+        # Load fields preset
+        config = Config("fields_editor")
+        presets = config["presets"] or {}
+        self.fields_menu.clear()
+        current_fields = self.model.fields
+        current_name = "< not set >"
+        for key, value in presets.items():
+            action = self.fields_menu.addAction(QIcon(), key)
+            action.setData(value)
+            if current_fields == value:
+                current_name = key
+
+        self.fields_menu.parent().setText(f"Fields: {current_name}")
+
+        # Load source preset
+        if self.conn:
+            self.source_menu.clear()
+            for rec in sql.get_selections(self.conn):
+                action = self.source_menu.addAction(QIcon(), rec["name"])
+                action.setData(rec["name"])
+        self.source_menu.parent().setText(f"Source: {self.model.source}")
+
+        # Load filters preset
+        config = Config("filters_editor")
+        presets = config["presets"] or {}
+        self.filters_menu.clear()
+        current_filters = self.model.filters
+        current_name = "< not set >"
+        act = self.filters_menu.addAction("Clear all filters")
+        act.setData({"$and": []})
+        self.filters_menu.addSeparator()
+        for key, value in presets.items():
+            action = self.filters_menu.addAction(key)
+            action.setData(value)
+
+            if str(current_filters) == str(value):
+                current_name = key
+
+        self.filters_menu.parent().setText(f"Filters: {current_name}")
+
     def auto_resize(self):
         """Resize columns to content"""
         self.view.resizeColumnsToContents()
@@ -1036,21 +1123,20 @@ class VariantView(QWidget):
     def load(self, reset_page: bool = False):
         """Load the view
 
-        If reset_page is set to True, also reset the page to 1
+        If reset_page is set to True, also reset the page to 1 and clear cache
 
         Args:
             reset_page (bool, optional):
         """
         if reset_page:
             self.model.page = 1
+            self.model.clear_all_cache()
             # self.model.order_by = None
 
         self.log_edit.hide()
         self.model.interrupt()
         self.model.load()
 
-        self.source_label.setText(self.model.source)
-
         # display sort indicator
         order_by = self.model.order_by
         if order_by:
@@ -1060,6 +1146,8 @@ class VariantView(QWidget):
                 index = self.model.fields.index(ordered_field)
                 self.view.horizontalHeader().setSortIndicator(index, order)
 
+        self.load_button_menu()
+
     def on_variant_loaded(self):
         """Slot called when async queries from the model are finished
         (especially count of variants for page box).
@@ -1329,7 +1417,9 @@ class VariantView(QWidget):
         current_variant = self.model.variant(index.row())
 
         # Get variant name
-        variant_name = cm.find_variant_name(conn=self.conn, variant_id=current_variant["id"], troncate=True)
+        variant_name = cm.find_variant_name(
+            conn=self.conn, variant_id=current_variant["id"], troncate=True
+        )
 
         menu.addAction(
             FIcon(0xF064F),
@@ -1367,7 +1457,7 @@ class VariantView(QWidget):
                 sample_valid = sample_info["classification"]
 
         # Menu Validation for sample
-        if sample_id and sample_name and variant_id:
+        if sample_id and sample_name and variant_id and current_variant[header_name]:
 
             # find genotype
             genotype = sql.get_sample_annotations(self.conn, variant_id, sample_id)
@@ -1420,7 +1510,7 @@ class VariantView(QWidget):
         Returns:
             locked (bool) : lock status of sample attached to current genotype
         """
-        config_classif = Config("classifications").get("samples", None)
+        config_classif = Config("classifications").get("samples", [])
         sample = sql.get_sample(self.conn, sample_id)
         sample_classif = sample.get("classification", None)
 
@@ -1716,6 +1806,10 @@ class VariantView(QWidget):
             variant = dict(self.model.variant(index.row()))
             if "id" in variant:
                 del variant["id"]
+            if "classification" in variant:
+                del variant["classification"]
+            if "favorite" in variant:
+                del variant["favorite"]
             writer.writerow(variant)
 
         QApplication.instance().clipboard().setText(output.getvalue())
@@ -1744,7 +1838,8 @@ class VariantView(QWidget):
         """
         Action on default doubleClick
         """
-        self.open_editor(index)
+        # self.open_editor(index)
+        self.update_favorites()
 
     def on_double_clicked_vertical_header(self, index: QModelIndex):
         """
@@ -1783,11 +1878,15 @@ class VariantView(QWidget):
         if header_name_match_sample:
             if validation_menu_lock:
                 QMessageBox.information(
-                    self, "Sample locked", self.tr(f"Sample '{sample_name}' is locked, genotype can not be changed")
+                    self,
+                    "Sample locked",
+                    self.tr(f"Sample '{sample_name}' is locked, genotype can not be changed"),
                 )
             elif no_genotype:
                 QMessageBox.information(
-                    self, "No genotype", self.tr(f"Sample '{sample_name}' does not have genotype for this variant")
+                    self,
+                    "No genotype",
+                    self.tr(f"Sample '{sample_name}' does not have genotype for this variant"),
                 )
             else:
                 self._show_sample_variant_dialog()
@@ -1840,6 +1939,9 @@ class VariantView(QWidget):
 
         config = Config("classifications")
         genotypes_classifications = config.get("genotypes", [])
+        genotypes_classifications = sorted(
+            genotypes_classifications, key=lambda d: d.get("number", 0)
+        )
 
         for item in genotypes_classifications:
 
@@ -1922,9 +2024,11 @@ class VariantViewWidget(plugin.PluginWidget):
         self.view.filter_remove.connect(self.on_filter_removed)
         self.view.field_remove.connect(self.on_field_removed)
 
-        self.view.fields_btn_clicked.connect(lambda: self.show_plugin("fields_editor"))
-        self.view.source_btn_clicked.connect(lambda: self.show_plugin("source_editor"))
-        self.view.filters_btn_clicked.connect(lambda: self.show_plugin("filters_editor"))
+        self.view.fields_menu_changed.connect(self.on_fields_changed)
+        self.view.source_menu_changed.connect(self.on_source_changed)
+        self.view.filters_menu_changed.connect(self.on_filters_changed)
+
+        self.view.vql_button_clicked.connect(self.on_vql_button_clicked)
 
     def show_plugin(self, name: str):
 
@@ -1933,6 +2037,30 @@ class VariantViewWidget(plugin.PluginWidget):
             dock = self.mainwindow.plugins[name].parent()
             dock.setVisible(not dock.isVisible())
 
+    def on_vql_button_clicked(self):
+        self.mainwindow.toggle_footer_visibility()
+
+    def on_fields_changed(self, fields: list):
+        if fields:
+            self.view.model.fields = fields
+            self.view.load()
+            self.mainwindow.set_state_data("fields", fields)
+            self.mainwindow.refresh_plugins(sender=self)
+
+    def on_source_changed(self, source: str):
+        if source:
+            self.view.model.source = source
+            self.view.load()
+            self.mainwindow.set_state_data("source", source)
+            self.mainwindow.refresh_plugins(sender=self)
+
+    def on_filters_changed(self, filters: dict):
+        if filters:
+            self.view.model.filters = filters
+            self.view.load()
+            self.mainwindow.set_state_data("filters", filters)
+            self.mainwindow.refresh_plugins(sender=self)
+
     def on_load_finished(self):
         """Triggered when variant load is finished
         Notify all plugins registered to "executed_query_data"
@@ -1946,7 +2074,7 @@ class VariantViewWidget(plugin.PluginWidget):
 
         self.mainwindow.set_state_data("executed_query_data", executed_query_data)
         self.mainwindow.set_state_data("order_by", self.view.model.order_by)
-        self.mainwindow.refresh_plugins()
+        self.mainwindow.refresh_plugins(sender=self)
 
     def on_field_removed(self, field: str):
 
@@ -2005,7 +2133,10 @@ class VariantViewWidget(plugin.PluginWidget):
         self.view.model.set_cache(config.get("memory_cache", 32))
 
         config = Config("classifications")
-        self.view.model.classifications = list(config.get("variants", []))
+        self.view.model.classifications = config.get("variants", [])
+        self.view.model.classifications = sorted(
+            self.view.model.classifications, key=lambda d: d.get("number", 0)
+        )
 
         self.on_refresh()
 
