@@ -401,9 +401,7 @@ class VcfImportWidget(QWidget):
         return self.import_id.text()
 
     def pedfile(self):
-        _, filename = tempfile.mkstemp()
-        self.samples_widget.view.model.to_pedfile(filename)
-        return filename
+        return self.samples_widget.view.pedfile
 
     def get_ignored_fields(self):
         return self.fields_widget.model.get_ignored_fields()
@@ -500,6 +498,8 @@ class ImportThread(QThread):
         self.db_filename = None
         # File top open
         self.filename = None
+        # Projet settings
+        self.project = None
         # Import ID
         self.import_id = None
         # pedfile
@@ -553,6 +553,7 @@ class ImportThread(QThread):
                     self.conn,
                     reader,
                     pedfile=self.pedfile,
+                    project = self.project,
                     import_id=import_id,
                     ignored_fields=self.ignored_fields,
                     indexed_fields=self.indexed_fields,
